package com.ruoyi.post.frequency.posreport.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.post.controller.req.PostReportReq;
import com.ruoyi.post.frequency.posreport.entity.PostReport;
import com.ruoyi.response.ResponseData;
import com.ruoyi.vo.UserVo;

import java.util.List;

/**
 * 论坛举报Service接口
 * 
 * @author liwenlong
 * @date 2023-10-26
 */
public interface PostReportService extends IService<PostReport>
{
    /**
     * 查询论坛举报
     * 
     * @param id 论坛举报主键
     * @return 论坛举报
     */
    public PostReport selectPostReportById(Long id);

    /**
     * 查询论坛举报列表
     * 
     * @param postReport 论坛举报
     * @return 论坛举报集合
     */
    public List<PostReport> selectPostReportList(PostReport postReport);

    /**
     * 新增论坛举报
     * 
     * @param postReport 论坛举报
     * @return 结果
     */
    public int insertPostReport(PostReport postReport);

    /**
     * 修改论坛举报
     * 
     * @param postReport 论坛举报
     * @return 结果
     */
    public int updatePostReport(PostReport postReport);

    /**
     * 批量删除论坛举报
     * 
     * @param ids 需要删除的论坛举报主键集合
     * @return 结果
     */
    public int deletePostReportByIds(Long[] ids,Integer delFlag);

    /**
     * 删除论坛举报信息
     * 
     * @param id 论坛举报主键
     * @return 结果
     */
    public int deletePostReportById(Long id);

    /**
     * 举报处理
     * @param postReport
     * @return
     */
    AjaxResult handle(PostReport postReport);

    /**
     * 帖子举报
     * @param req
     * @param userVo
     * @return
     */
    ResponseData postReport(PostReportReq req, UserVo userVo);

}
